import { DocumentNode } from 'graphql';
import { Hooks } from 'ky-universal';
interface DraqulaOptions {
    readonly retry?: boolean | number | DraqulaOptionsRetry;
    readonly hooks?: Hooks;
    readonly timeout?: number;
    readonly cache?: boolean;
}
interface DraqulaOptionsRetry {
    readonly retries?: number;
    readonly factor?: number;
    readonly minTimeout?: number;
    readonly maxTimeout?: number;
    readonly randomize?: boolean;
}
interface QueryOptions {
    readonly signal?: AbortSignal;
    readonly retry?: boolean;
    readonly timeout?: number;
    readonly cache?: boolean;
}
interface MutateOptions {
    readonly refetchQueries?: boolean | DocumentNode[];
    readonly waitForRefetchQueries?: boolean;
}
export default class Draqula {
    readonly url: string;
    readonly options: DraqulaOptions;
    private readonly events;
    private graph;
    private queryCache;
    private queryIds;
    private readonly dataCache;
    constructor(url: string, options?: DraqulaOptions);
    private createQuery;
    private getQueryId;
    private getCacheKey;
    setDataCache<T>(query: DocumentNode, variables: object, data: T | undefined): void;
    getDataCache<T>(query: DocumentNode, variables: object): T | undefined;
    private rawQuery;
    query<T>(query: DocumentNode, variables: object, options: QueryOptions): Promise<T>;
    preload<T>(query: DocumentNode, variables?: object): Promise<void>;
    watchQuery(query: DocumentNode, callback: (queryId: string) => any): () => void;
    private refetchQueries;
    mutate<T>(query: DocumentNode, variables: object, options: MutateOptions): Promise<T>;
    clearCache(): void;
    destroy(): void;
}
export {};
